Skip to contents

If the orchestr package is available, wraps a knowledge_store so it can be used in orchestr agent graphs.

Usage

as_orchestr_memory(ks)

Arguments

ks

A knowledge_store object.

Value

A list with get and set functions compatible with orchestr memory interface.

Examples

ks <- knowledge_store$new()
mem <- as_orchestr_memory(ks)
mem$set("key", "value")
mem$get("key")
#> [1] "value"