Approximates the number of tokens using either a word-based or character-based method.
Usage
count_tokens(text, method = c("words", "chars"))Approximates the number of tokens using either a word-based or character-based method.
count_tokens(text, method = c("words", "chars"))