Builds a TF-IDF vocabulary from a corpus and returns an embedder that can embed new texts into that vocabulary space. No external API required.
Examples
emb <- embed_tfidf(c("the cat sat", "the dog ran"))
Builds a TF-IDF vocabulary from a corpus and returns an embedder that can embed new texts into that vocabulary space. No external API required.
emb <- embed_tfidf(c("the cat sat", "the dog ran"))